Archive

Enum Archive 

pub enum Archive {
Show 29 variants Epub, Zip, Tar, Rar, Gz, Bz2, Bz3, SevenZ, Xz, Pdf, Swf, Rtf, Eot, Ps, Sqlite, Nes, Crx, Cab, Deb, Ar, Z, Lz, Rpm, Dcm, Zst, Lz4, Msi, Cpio, Par2,
}
Archive and compressed file formats.

Supports various compression and archive formats, as well as some document types.

Variants



Epub

Electronic Publication format (EPUB)



Zip

ZIP archive format



Tar

TAR archive format



Rar

RAR archive format



Gz

GZIP compressed format



Bz2

BZIP2 compressed format



Bz3

BZIP3 compressed format



SevenZ

7-Zip archive format



Xz

XZ compressed format



Pdf

Portable Document Format



Swf

Shockwave Flash format



Rtf

Rich Text Format



Eot

Embedded OpenType font



Ps

PostScript document



Sqlite

SQLite database format



Nes

Nintendo NES ROM format



Crx

Chrome extension format



Cab

Microsoft Cabinet archive



Deb

Debian package format



Ar

Unix archive format



Z

Unix compress format



Lz

LZIP compressed format



Rpm

RPM package format



Dcm

DICOM medical image format



Zst

Zstandard compressed format



Lz4

LZ4 compressed format



Msi

Microsoft Installer package



Cpio

CPIO archive format



Par2

PAR2 parity archive